@@ -1,6 +1,7 @@
 #if !defined(SIMDE_TESTS_H)
 #define SIMDE_TESTS_H
 
+#include "../simde/hedley.h"
 #include "../simde/simde-common.h"
 #include "../simde/simde-f16.h"
 
@@ -17,19 +18,30 @@ typedef enum SimdeTestVecPos {
   SIMDE_TEST_VEC_POS_LAST   = -1
 } SimdeTestVecPos;
 
-HEDLEY_DIAGNOSTIC_PUSH
-SIMDE_DIAGNOSTIC_DISABLE_VLA_
-HEDLEY_DIAGNOSTIC_DISABLE_UNUSED_FUNCTION
+
+/* all tests benefit from these */
 SIMDE_DIAGNOSTIC_DISABLE_PADDED_
+SIMDE_DIAGNOSTIC_DISABLE_CPP98_COMPAT_PEDANTIC_
+SIMDE_DIAGNOSTIC_DISABLE_VLA_
+SIMDE_DIAGNOSTIC_DISABLE_DISABLED_MACRO_EXPANSION_
+SIMDE_DIAGNOSTIC_DISABLE_BUGGY_CASTS_
+SIMDE_DIAGNOSTIC_DISABLE_RESERVED_ID_
+SIMDE_DIAGNOSTIC_DISABLE_C99_EXTENSIONS_
+SIMDE_DIAGNOSTIC_DISABLE_USED_BUT_MARKED_UNUSED_
+
+#if defined(HEDLEY_GCC_VERSION) && !(HEDLEY_GCC_VERSION_CHECK(6,0,0))
+HEDLEY_DIAGNOSTIC_DISABLE_UNUSED_FUNCTION
+#endif
+
+HEDLEY_DIAGNOSTIC_PUSH
+HEDLEY_DIAGNOSTIC_DISABLE_UNUSED_FUNCTION
 SIMDE_DIAGNOSTIC_DISABLE_ZERO_AS_NULL_POINTER_CONSTANT_
 SIMDE_DIAGNOSTIC_DISABLE_CAST_FUNCTION_TYPE_
 SIMDE_DIAGNOSTIC_DISABLE_NON_CONSTANT_AGGREGATE_INITIALIZER_
 SIMDE_DIAGNOSTIC_DISABLE_C99_EXTENSIONS_
 SIMDE_DIAGNOSTIC_DISABLE_DECLARATION_AFTER_STATEMENT_
 SIMDE_DIAGNOSTIC_DISABLE_NO_EMMS_INSTRUCTION_
-SIMDE_DIAGNOSTIC_DISABLE_CPP98_COMPAT_PEDANTIC_
 SIMDE_DIAGNOSTIC_DISABLE_ANNEX_K_
-SIMDE_DIAGNOSTIC_DISABLE_DISABLED_MACRO_EXPANSION_
 
 #if \
     HEDLEY_HAS_BUILTIN(__builtin_abort) || \
@@ -697,17 +709,17 @@ simde_assert_equal_vf16_(
   for (size_t i = 0 ; i < vec_len ; i++) {
     simde_float32 a_ = simde_float16_to_float32(a[i]);
     simde_float32 b_ = simde_float16_to_float32(b[i]);
-    
+
     if (HEDLEY_UNLIKELY(!simde_test_equal_f32(a_, b_, slop_))) {
       simde_test_debug_printf_("%s:%d: assertion failed: %s[%zu] ~= %s[%zu] (%f ~= %f)\n",
-              filename, line, astr, i, bstr, i, HEDLEY_STATIC_CAST(double, a_), 
+              filename, line, astr, i, bstr, i, HEDLEY_STATIC_CAST(double, a_),
               HEDLEY_STATIC_CAST(double, b_));
       SIMDE_TEST_ASSERT_RETURN(1);
     }
   }
   return 0;
 }
-#define simde_assert_equal_vf16(vec_len, a, b, precision) simde_assert_equal_vf16_(vec_len, a, b, simde_test_f16_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)
+#define simde_assert_equal_vf16(vec_len, a, b, precision) do { if (simde_assert_equal_vf16_(vec_len, a, b, simde_test_f16_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)) { return 1; } } while (0)
 
 static int
 simde_assert_equal_f16_(simde_float16 a, simde_float16 b, simde_float16 slop,
@@ -723,7 +735,7 @@ simde_assert_equal_f16_(simde_float16 a, simde_float16 b, simde_float16 slop,
   }
   return 0;
 }
-#define simde_assert_equal_f16(a, b, precision) simde_assert_equal_f16_(a, b, simde_test_f16_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)
+#define simde_assert_equal_f16(a, b, precision) do { if (simde_assert_equal_f16_(a, b, simde_test_f16_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)) { return 1; } } while (0)
 
 static int
 simde_assert_equal_vf32_(
@@ -738,7 +750,7 @@ simde_assert_equal_vf32_(
   }
   return 0;
 }
-#define simde_assert_equal_vf32(vec_len, a, b, precision) simde_assert_equal_vf32_(vec_len, a, b, simde_test_f32_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)
+#define simde_assert_equal_vf32(vec_len, a, b, precision) do { if (simde_assert_equal_vf32_(vec_len, a, b, simde_test_f32_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)) { return 1; } } while (0)
 
 static int
 simde_assert_equal_f32_(simde_float32 a, simde_float32 b, simde_float32 slop,
@@ -750,7 +762,7 @@ simde_assert_equal_f32_(simde_float32 a, simde_float32 b, simde_float32 slop,
   }
   return 0;
 }
-#define simde_assert_equal_f32(a, b, precision) simde_assert_equal_f32_(a, b, simde_test_f32_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)
+#define simde_assert_equal_f32(a, b, precision) do { if (simde_assert_equal_f32_(a, b, simde_test_f32_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)) { return 1; } } while (0)
 
 static int
 simde_assert_equal_vf64_(
@@ -765,7 +777,7 @@ simde_assert_equal_vf64_(
   }
   return 0;
 }
-#define simde_assert_equal_vf64(vec_len, a, b, precision) simde_assert_equal_vf64_(vec_len, a, b, simde_test_f64_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)
+#define simde_assert_equal_vf64(vec_len, a, b, precision) do { if (simde_assert_equal_vf64_(vec_len, a, b, simde_test_f64_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)) { return 1; } } while (0)
 
 static int
 simde_assert_equal_f64_(simde_float64 a, simde_float64 b, simde_float64 slop,
@@ -777,7 +789,7 @@ simde_assert_equal_f64_(simde_float64 a, simde_float64 b, simde_float64 slop,
   }
   return 0;
 }
-#define simde_assert_equal_f64(a, b, precision) simde_assert_equal_f64_(a, b, simde_test_f64_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)
+#define simde_assert_equal_f64(a, b, precision) do { if (simde_assert_equal_f64_(a, b, simde_test_f64_precision_to_slop(precision), __FILE__, __LINE__, #a, #b)) { return 1; } } while (0)
 
 #define SIMDE_TEST_GENERATE_ASSERT_EQUAL_FUNC_(T, symbol_identifier, fmt) \
   static int \
@@ -956,4 +968,7 @@ SIMDE_TEST_GENERATE_ASSERT_EQUAL_FUNC_(uint64_t, u64, PRIu64)
     HEDLEY_C_DECL MunitSuite* HEDLEY_CONCAT(name, _emul_cpp)(void);
 #endif
 
+HEDLEY_DIAGNOSTIC_POP
+
+
 #endif /* !defined(SIMDE_TESTS_H) */
